(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 10.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[      6919,        234]
NotebookOptionsPosition[      5932,        195]
NotebookOutlinePosition[      6291,        211]
CellTagsIndexPosition[      6248,        208]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["\<\
Equation 1 and 2 are the equations for the concentration in domain 1 and 2 \
respectively. These equations are in Laplace space.\
\>", "Text",
 CellChangeTimes->{{3.635594033466125*^9, 3.635594089464183*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
  
  RowBox[{"Eq1", ":=", 
   RowBox[{
    RowBox[{
     RowBox[{"s", "*", "c1"}], "-", "1"}], "==", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "alpha"}], "*", "c1"}], "+", 
     RowBox[{"alpha", "*", "c2"}]}]}]}]}]], "Input",
 CellChangeTimes->{{3.635503811509617*^9, 3.635503838047748*^9}, 
   3.6355039280486717`*^9, {3.635519993924975*^9, 3.635519994494556*^9}, {
   3.635594002739477*^9, 3.6355940307861633`*^9}}],

Cell[BoxData[
 RowBox[{"Eq2", ":=", 
  RowBox[{
   RowBox[{"beta", "*", "s", "*", "c2"}], "==", 
   RowBox[{
    RowBox[{"alpha", "*", "c1"}], "-", 
    RowBox[{"alpha", "*", "c2"}]}]}]}]], "Input",
 CellChangeTimes->{{3.635503840883565*^9, 3.6355038648204203`*^9}, 
   3.635503933312801*^9}],

Cell[CellGroupData[{

Cell[BoxData["Eq1"], "Input",
 CellChangeTimes->{{3.6355038682932463`*^9, 3.635503868930193*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "1"}], "+", 
   RowBox[{"c1", " ", "s"}]}], "\[Equal]", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "alpha"}], " ", "c1"}], "+", 
   RowBox[{"alpha", " ", "c2"}]}]}]], "Output",
 CellChangeTimes->{
  3.635503870069364*^9, 3.63550393800692*^9, {3.63550480740449*^9, 
   3.6355048236603403`*^9}, 3.635519998380714*^9, {3.635594095571577*^9, 
   3.635594112022352*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["Eq2"], "Input",
 CellChangeTimes->{{3.6355038957191353`*^9, 3.635503900312275*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"beta", " ", "c2", " ", "s"}], "\[Equal]", 
  RowBox[{
   RowBox[{"alpha", " ", "c1"}], "-", 
   RowBox[{"alpha", " ", "c2"}]}]}]], "Output",
 CellChangeTimes->{{3.635503896486285*^9, 3.635503900660453*^9}, 
   3.635503940812491*^9, 3.6355048256057158`*^9, 3.635520006052167*^9, 
   3.635594113389255*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Solve", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"Eq1", ",", "Eq2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"c1", ",", "c2"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.63550394842336*^9, 3.6355039787776814`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"c1", "\[Rule]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        RowBox[{"-", "alpha"}], "-", 
        RowBox[{"beta", " ", "s"}]}], 
       RowBox[{"s", " ", 
        RowBox[{"(", 
         RowBox[{"alpha", "+", 
          RowBox[{"alpha", " ", "beta"}], "+", 
          RowBox[{"beta", " ", "s"}]}], ")"}]}]]}]}], ",", 
    RowBox[{"c2", "\[Rule]", 
     FractionBox["alpha", 
      RowBox[{"s", " ", 
       RowBox[{"(", 
        RowBox[{"alpha", "+", 
         RowBox[{"alpha", " ", "beta"}], "+", 
         RowBox[{"beta", " ", "s"}]}], ")"}]}]]}]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{
  3.635503979092354*^9, {3.635504801140221*^9, 3.6355048269033833`*^9}, 
   3.635520008774501*^9, 3.6355941156522617`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"c1", ":=", 
  FractionBox[
   RowBox[{"alpha", " ", "+", 
    RowBox[{"beta", "  ", "s"}]}], 
   RowBox[{"s", " ", 
    RowBox[{"(", 
     RowBox[{"alpha", "+", 
      RowBox[{"alpha", " ", "beta"}], "+", 
      RowBox[{"beta", " ", "s"}]}], ")"}]}]]}]], "Input",
 CellChangeTimes->{{3.635504030489431*^9, 3.6355040318715763`*^9}, {
  3.6355048321128273`*^9, 3.6355048355182343`*^9}, {3.6355202324498997`*^9, 
  3.635520242753381*^9}}],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.635504035584174*^9, 3.635504077665678*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"InverseLaplaceTransform", "[", 
  RowBox[{"c1", ",", "s", ",", "t"}], "]"}]], "Input",
 CellChangeTimes->{{3.6355040860442753`*^9, 3.635504096895389*^9}, {
  3.63550464931394*^9, 3.635504662792461*^9}, {3.6355047079916677`*^9, 
  3.6355047357846193`*^9}, {3.635504842504931*^9, 3.6355048427419662`*^9}}],

Cell[BoxData[
 RowBox[{"c1", " ", 
  RowBox[{"DiracDelta", "[", "t", "]"}]}]], "Output",
 CellChangeTimes->{
  3.635504843268346*^9, {3.635520236881481*^9, 3.635520246184581*^9}, 
   3.6355941209541817`*^9}]
}, Open  ]],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.635504782486311*^9, 3.6355047983267813`*^9}, 
   3.63550486257653*^9}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"c2", ":=", 
  FractionBox[
   RowBox[{"alpha", " "}], 
   RowBox[{"s", " ", 
    RowBox[{"(", 
     RowBox[{"alpha", "+", 
      RowBox[{"alpha", " ", "beta"}], "+", 
      RowBox[{"beta", " ", "s"}]}], ")"}]}]]}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{"InverseLaplaceTransform", "[", 
   RowBox[{"c2", ",", "s", ",", "t"}], "]"}], "]"}]}], "Input",
 CellChangeTimes->{{3.6355048761123953`*^9, 3.635504889022172*^9}, {
  3.63552057688207*^9, 3.6355205897526484`*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{"1", "-", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{"alpha", " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", "beta"}], ")"}], " ", "t"}], "beta"]}]]}], 
  RowBox[{"1", "+", "beta"}]]], "Output",
 CellChangeTimes->{
  3.635504889858747*^9, {3.6355205737527237`*^9, 3.635520590020259*^9}, 
   3.6355941228817053`*^9}]
}, Open  ]]
},
WindowSize->{808, 911},
WindowMargins->{{109, Automatic}, {220, Automatic}},
FrontEndVersion->"10.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (December 4, \
2014)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 218, 4, 49, "Text"],
Cell[779, 26, 515, 13, 80, "Input"],
Cell[1297, 41, 292, 8, 28, "Input"],
Cell[CellGroupData[{
Cell[1614, 53, 97, 1, 28, "Input"],
Cell[1714, 56, 414, 12, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2165, 73, 97, 1, 28, "Input"],
Cell[2265, 76, 339, 8, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2641, 89, 252, 7, 28, "Input"],
Cell[2896, 98, 807, 24, 50, "Output"]
}, Open  ]],
Cell[3718, 125, 459, 12, 51, "Input"],
Cell[4180, 139, 92, 1, 28, "Input"],
Cell[CellGroupData[{
Cell[4297, 144, 327, 5, 28, "Input"],
Cell[4627, 151, 207, 5, 28, "Output"]
}, Open  ]],
Cell[4849, 159, 119, 2, 28, "Input"],
Cell[CellGroupData[{
Cell[4993, 165, 515, 13, 71, "Input"],
Cell[5511, 180, 405, 12, 58, "Output"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
