(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 10.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[     14612,        474]
NotebookOptionsPosition[     12807,        413]
NotebookOutlinePosition[     13165,        429]
CellTagsIndexPosition[     13122,        426]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["\<\
Equation 1 is the concentration in the mobile domain, written in Fourier - \
Laplace space.\
\>", "Text",
 CellChangeTimes->{{3.635594149160783*^9, 3.63559416195175*^9}, {
  3.635680606169333*^9, 3.635680608991671*^9}}],

Cell[BoxData[
 RowBox[{"Eq1", ":=", 
  RowBox[{
   RowBox[{
    RowBox[{"s", "*", "c1"}], "-", "1", "+", 
    RowBox[{"d", "*", 
     RowBox[{"k", "^", "2"}], "*", "c1"}]}], "==", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "alpha"}], "*", "c1"}], "+", 
    RowBox[{
     RowBox[{
      RowBox[{"alpha", "^", "2"}], "/", 
      RowBox[{"(", 
       RowBox[{"alpha", "+", 
        RowBox[{"beta", "*", "s"}]}], ")"}]}], "*", "c1"}]}]}]}]], "Input",
 CellChangeTimes->{{3.635508082061467*^9, 3.635508160873159*^9}, {
   3.635508200754736*^9, 3.635508204905547*^9}, 3.635508241275868*^9, {
   3.635508315459791*^9, 3.635508316758643*^9}, {3.635678313513968*^9, 
   3.635678317307332*^9}, {3.6356783480358353`*^9, 3.635678348353484*^9}, {
   3.635679626655417*^9, 3.635679671217247*^9}}],

Cell[CellGroupData[{

Cell[BoxData["Eq1"], "Input",
 CellChangeTimes->{{3.6355081624531937`*^9, 3.635508162921994*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "1"}], "+", 
   RowBox[{"c1", " ", "d", " ", 
    SuperscriptBox["k", "2"]}], "+", 
   RowBox[{"c1", " ", "s"}]}], "\[Equal]", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "alpha"}], " ", "c1"}], "+", 
   FractionBox[
    RowBox[{
     SuperscriptBox["alpha", "2"], " ", "c1"}], 
    RowBox[{"alpha", "+", 
     RowBox[{"beta", " ", "s"}]}]]}]}]], "Output",
 CellChangeTimes->{
  3.635678481475637*^9, {3.635679632793426*^9, 3.635679673514845*^9}, 
   3.635680140087636*^9, 3.635680626213356*^9, 3.6356810950171127`*^9, 
   3.635681162332036*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Solve", "[", 
  RowBox[{"Eq1", ",", "c1"}], "]"}]], "Input",
 CellChangeTimes->{{3.635679658858315*^9, 3.635679664172595*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"c1", "\[Rule]", 
    FractionBox[
     RowBox[{"alpha", "+", 
      RowBox[{"beta", " ", "s"}]}], 
     RowBox[{
      RowBox[{"alpha", " ", "d", " ", 
       SuperscriptBox["k", "2"]}], "+", 
      RowBox[{"alpha", " ", "s"}], "+", 
      RowBox[{"alpha", " ", "beta", " ", "s"}], "+", 
      RowBox[{"beta", " ", "d", " ", 
       SuperscriptBox["k", "2"], " ", "s"}], "+", 
      RowBox[{"beta", " ", 
       SuperscriptBox["s", "2"]}]}]]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{{3.635679664642724*^9, 3.635679675799686*^9}, 
   3.6356801415581417`*^9, 3.635680627549749*^9, 3.6356810964912977`*^9, 
   3.635681164396181*^9}]
}, Open  ]],

Cell["\<\
We now have a solution for c1, which we will invert back into Laplace space\
\>", "Text",
 CellChangeTimes->{{3.635680644216298*^9, 3.635680660295603*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"InverseFourierTransform", "[", 
   RowBox[{
    FractionBox[
     RowBox[{"alpha", "+", 
      RowBox[{"beta", " ", "s"}]}], 
     RowBox[{
      RowBox[{"alpha", " ", "d", " ", 
       SuperscriptBox["k", "2"]}], "+", 
      RowBox[{"alpha", " ", "s"}], "+", 
      RowBox[{"alpha", " ", "beta", " ", "s"}], "+", 
      RowBox[{"beta", " ", "d", " ", 
       SuperscriptBox["k", "2"], " ", "s"}], "+", 
      RowBox[{"beta", " ", 
       SuperscriptBox["s", "2"]}]}]], ",", "k", ",", "x", ",", 
    RowBox[{"FourierParameters", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"1", ",", "1"}], "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6356796980204153`*^9, 3.635679711003689*^9}, {
  3.635679745088427*^9, 3.635679746117949*^9}, {3.6356801338391123`*^9, 
  3.6356801357383347`*^9}, {3.635680630426503*^9, 3.635680630936407*^9}, {
  3.635680661651415*^9, 3.635680662435361*^9}, {3.635680943512343*^9, 
  3.63568094683208*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{"Abs", "[", "x", "]"}], 
      SqrtBox[
       FractionBox[
        RowBox[{"d", " ", 
         RowBox[{"(", 
          RowBox[{"alpha", "+", 
           RowBox[{"beta", " ", "s"}]}], ")"}]}], 
        RowBox[{"s", " ", 
         RowBox[{"(", 
          RowBox[{"alpha", "+", 
           RowBox[{"alpha", " ", "beta"}], "+", 
           RowBox[{"beta", " ", "s"}]}], ")"}]}]]]]}]], " ", 
   SqrtBox[
    FractionBox[
     RowBox[{"d", " ", 
      RowBox[{"(", 
       RowBox[{"alpha", "+", 
        RowBox[{"beta", " ", "s"}]}], ")"}]}], 
     RowBox[{"s", " ", 
      RowBox[{"(", 
       RowBox[{"alpha", "+", 
        RowBox[{"alpha", " ", "beta"}], "+", 
        RowBox[{"beta", " ", "s"}]}], ")"}]}]]]}], 
  RowBox[{"2", " ", "d"}]]], "Output",
 CellChangeTimes->{{3.635679717237505*^9, 3.635679746955496*^9}, 
   3.635680149803636*^9, 3.635680954227511*^9, 3.6356811061616573`*^9, 
   3.635681173003636*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"solution", ":=", 
   FractionBox[
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{"Abs", "[", "x", "]"}], 
        SqrtBox[
         FractionBox[
          RowBox[{"d", " ", 
           RowBox[{"(", 
            RowBox[{"alpha", "+", 
             RowBox[{"beta", " ", "s"}]}], ")"}]}], 
          RowBox[{"s", " ", 
           RowBox[{"(", 
            RowBox[{"alpha", "+", 
             RowBox[{"alpha", " ", "beta"}], "+", 
             RowBox[{"beta", " ", "s"}]}], ")"}]}]]]]}]], " ", 
     SqrtBox[
      FractionBox[
       RowBox[{"d", " ", 
        RowBox[{"(", 
         RowBox[{"alpha", "+", 
          RowBox[{"beta", " ", "s"}]}], ")"}]}], 
       RowBox[{"s", " ", 
        RowBox[{"(", 
         RowBox[{"alpha", "+", 
          RowBox[{"alpha", " ", "beta"}], "+", 
          RowBox[{"beta", " ", "s"}]}], ")"}]}]]]}], 
    RowBox[{"2", " ", "d"}]]}], "\[IndentingNewLine]"}]], "Input",
 CellChangeTimes->{{3.635678476417514*^9, 3.6356784833162394`*^9}, {
   3.6356797594921494`*^9, 3.635679768596002*^9}, {3.635680195702837*^9, 
   3.6356802045872498`*^9}, 3.6356809685903873`*^9}],

Cell["Let\[CloseCurlyQuote]s check if we can invert", "Text",
 CellChangeTimes->{{3.635681268461741*^9, 3.6356812749568567`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"InverseLaplaceTransform", "[", 
  RowBox[{"solution", ",", "s", ",", "t"}], "]"}]], "Input",
 CellChangeTimes->{{3.635681279216117*^9, 3.635681286781446*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{"InverseLaplaceTransform", "[", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{"Abs", "[", "x", "]"}], 
        SqrtBox[
         FractionBox[
          RowBox[{"d", " ", 
           RowBox[{"(", 
            RowBox[{"alpha", "+", 
             RowBox[{"beta", " ", "s"}]}], ")"}]}], 
          RowBox[{"s", " ", 
           RowBox[{"(", 
            RowBox[{"alpha", "+", 
             RowBox[{"alpha", " ", "beta"}], "+", 
             RowBox[{"beta", " ", "s"}]}], ")"}]}]]]]}]], " ", 
     SqrtBox[
      FractionBox[
       RowBox[{"d", " ", 
        RowBox[{"(", 
         RowBox[{"alpha", "+", 
          RowBox[{"beta", " ", "s"}]}], ")"}]}], 
       RowBox[{"s", " ", 
        RowBox[{"(", 
         RowBox[{"alpha", "+", 
          RowBox[{"alpha", " ", "beta"}], "+", 
          RowBox[{"beta", " ", "s"}]}], ")"}]}]]]}], ",", "s", ",", "t"}], 
   "]"}], 
  RowBox[{"2", " ", "d"}]]], "Output",
 CellChangeTimes->{3.6356813228595963`*^9}]
}, Open  ]],

Cell["No luck, wo we will have to ask Matlab again, but \
that\[CloseCurlyQuote]s ok.", "Text",
 CellChangeTimes->{{3.635681346189412*^9, 3.6356813631725807`*^9}}],

Cell["\<\

Just in case, let\[CloseCurlyQuote]s check if our answer actually makes \
sense. If alpha=0 we should get the diffusion equation solution\
\>", "Text",
 CellChangeTimes->{{3.6356807972716503`*^9, 3.6356808145507708`*^9}, {
  3.635681179549493*^9, 3.635681183389481*^9}, {3.635681367612468*^9, 
  3.635681380940568*^9}}],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.6356807879303427`*^9, 3.635680792818091*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"alpha", ":=", "0"}]}]], "Input",
 CellChangeTimes->{{3.635680207777095*^9, 3.635680209641632*^9}, {
   3.635680679624345*^9, 3.635680679975919*^9}, 3.635680817130279*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", "solution", "]"}]], "Input",
 CellChangeTimes->{{3.635680210970912*^9, 3.635680240449677*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{"Abs", "[", "x", "]"}], 
      SqrtBox[
       FractionBox["d", "s"]]]}]], " ", 
   SqrtBox[
    FractionBox["d", "s"]]}], 
  RowBox[{"2", " ", "d"}]]], "Output",
 CellChangeTimes->{{3.6356802125649767`*^9, 3.635680240783352*^9}, 
   3.635680974065076*^9}]
}, Open  ]],

Cell["which we do...", "Text",
 CellChangeTimes->{{3.635680844407587*^9, 3.635680849206551*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"LaplaceTransform", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"1", "/", 
     RowBox[{"Sqrt", "[", 
      RowBox[{"4", "*", "Pi", "*", "d", "*", "t"}], "]"}]}], "*", 
    RowBox[{"Exp", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         RowBox[{"x", "^", "2"}]}], "/", "4"}], "/", "d"}], "/", "t"}], 
     "]"}]}], ",", "t", ",", "s"}], "]"}]], "Input",
 CellChangeTimes->{{3.6356784859123297`*^9, 3.635678485919091*^9}, {
  3.635680861519969*^9, 3.635680890127199*^9}}],

Cell[BoxData[
 FractionBox[
  SuperscriptBox["\[ExponentialE]", 
   RowBox[{"-", 
    FractionBox["1", 
     SqrtBox[
      FractionBox["d", 
       RowBox[{"s", " ", 
        SuperscriptBox["x", "2"]}]]]]}]], 
  RowBox[{"2", " ", 
   SqrtBox["d"], " ", 
   SqrtBox["s"]}]]], "Output",
 CellChangeTimes->{3.6356808948830547`*^9, 3.635680980841133*^9}]
}, Open  ]],

Cell["\<\
If you check both these expressions are the same, but just as a gut check let\
\[CloseCurlyQuote]s do the inverse transform also\
\>", "Text",
 CellChangeTimes->{{3.6356810204227533`*^9, 3.6356810320540123`*^9}, {
  3.63568106355785*^9, 3.635681074973735*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"InverseLaplaceTransform", "[", 
  RowBox[{
   FractionBox[
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{"Abs", "[", "x", "]"}], 
        SqrtBox[
         FractionBox["d", "s"]]]}]], " ", 
     SqrtBox[
      FractionBox["d", "s"]]}], 
    RowBox[{"2", " ", "d"}]], ",", "s", ",", "t"}], "]"}]], "Input",
 CellChangeTimes->{{3.635681040696933*^9, 3.63568105579893*^9}}],

Cell[BoxData[
 RowBox[{"ConditionalExpression", "[", 
  RowBox[{
   FractionBox[
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"-", 
       FractionBox[
        SuperscriptBox[
         RowBox[{"Abs", "[", "x", "]"}], "2"], 
        RowBox[{"4", " ", "d", " ", "t"}]]}]], " ", 
     SqrtBox[
      FractionBox["1", "t"]]}], 
    RowBox[{"2", " ", 
     SqrtBox["d"], " ", 
     SqrtBox["\[Pi]"]}]], ",", 
   RowBox[{
    FractionBox[
     RowBox[{"Abs", "[", "x", "]"}], 
     SqrtBox["d"]], ">", "0"}]}], "]"}]], "Output",
 CellChangeTimes->{3.635681056766823*^9}]
}, Open  ]],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.635508207529976*^9, 3.63550821896279*^9}}],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.6356784632331543`*^9, 3.635678463239435*^9}}],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.635508166983863*^9, 3.63550818564915*^9}, 
   3.635680821491234*^9}],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.635680823838973*^9, 3.635680825258019*^9}}],

Cell["", "Text",
 CellChangeTimes->{{3.635594179816697*^9, 3.63559420451153*^9}, 
   3.635680826838723*^9}],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.635508725122897*^9, 3.63550873639323*^9}, 
   3.635680830931682*^9}],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.6355087472975616`*^9, 3.6355087653618727`*^9}, 
   3.635680832889933*^9}],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.635680834366851*^9, 3.635680834372764*^9}}],

Cell["", "Text",
 CellChangeTimes->{{3.63559421906425*^9, 3.635594274951374*^9}, 
   3.635680835959489*^9}]
},
WindowSize->{808, 911},
WindowMargins->{{91, Automatic}, {Automatic, 182}},
FrontEndVersion->"10.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (December 4, \
2014)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 229, 5, 30, "Text"],
Cell[790, 27, 783, 20, 28, "Input"],
Cell[CellGroupData[{
Cell[1598, 51, 97, 1, 28, "Input"],
Cell[1698, 54, 593, 18, 52, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2328, 77, 150, 3, 28, "Input"],
Cell[2481, 82, 692, 18, 109, "Output"]
}, Open  ]],
Cell[3188, 103, 165, 3, 30, "Text"],
Cell[CellGroupData[{
Cell[3378, 110, 1014, 23, 117, "Input"],
Cell[4395, 135, 1040, 32, 92, "Output"]
}, Open  ]],
Cell[5450, 170, 1195, 34, 117, InheritFromParent],
Cell[6648, 206, 129, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[6802, 211, 182, 3, 28, "Input"],
Cell[6987, 216, 1062, 33, 92, "Output"]
}, Open  ]],
Cell[8064, 252, 163, 2, 30, "Text"],
Cell[8230, 256, 330, 7, 68, "Text"],
Cell[8563, 265, 94, 1, 28, "Input"],
Cell[8660, 268, 251, 4, 63, "Input"],
Cell[CellGroupData[{
Cell[8936, 276, 134, 2, 28, "Input"],
Cell[9073, 280, 383, 13, 91, "Output"]
}, Open  ]],
Cell[9471, 296, 96, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[9592, 301, 523, 15, 28, InheritFromParent],
Cell[10118, 318, 351, 12, 83, "Output"]
}, Open  ]],
Cell[10484, 333, 270, 5, 30, "Text"],
Cell[CellGroupData[{
Cell[10779, 342, 457, 14, 91, "Input"],
Cell[11239, 358, 586, 20, 79, "Output"]
}, Open  ]],
Cell[11840, 381, 91, 1, 28, "Input"],
Cell[11934, 384, 94, 1, 28, InheritFromParent],
Cell[12031, 387, 117, 2, 28, "Input"],
Cell[12151, 391, 92, 1, 28, InheritFromParent],
Cell[12246, 394, 107, 2, 30, "Text"],
Cell[12356, 398, 117, 2, 28, "Input"],
Cell[12476, 402, 122, 2, 28, "Input"],
Cell[12601, 406, 92, 1, 28, InheritFromParent],
Cell[12696, 409, 107, 2, 30, "Text"]
}
]
*)

(* End of internal cache information *)
